package POS::Admin::LdapStruct;

use strict;

use Exporter;
use vars qw(
  $VERSION @ISA @EXPORT
  %LDAP_STRUCT %LDAP_ATTR_STRUCT
  %EDIR_STRUCT %EDIR_ATTR_STRUCT
);
# SUSE Linux Enterprise Point Of Service 11 Service Pack 2 Feature Pack 4
$VERSION = 11.2.4;

@ISA = qw( Exporter );

#@LDAP_BASE_ACTIONS
@EXPORT = qw (
  %LDAP_STRUCT %LDAP_ATTR_STRUCT
  %EDIR_STRUCT %EDIR_ATTR_STRUCT
);

###############################################
# ldap objects hash:
# used in posAdmin.pl,
# to generate sc-pos.obj.schema
# and edir.schema
#  contains objects which are
#  in LDAP only
#  in LDAP and eDir and same
#  in LDAP and eDir but different
###############################################
%LDAP_STRUCT = (
    organization => {
        DESC        => 'The name of the organization represented in the LDAP tree.',
        objectClass => ['organization', 'top'],
        filter      => ['(objectClass=organization)'],
        attributes  => { must => ['o'], may => ['description'] },
        query       => { description => 'description of organization', dn => 'DN', o => 'name of organization' },
        default     => {},
        subentries  => [['scRefObjectContainer', '1'], ['organizationalUnit', '*'], ['scHardware', '1']]
    },
    organizationalUnit => {
        mode   => 'admin',
        master => ['o', 'ou'],
        DESC =>
'Organizational units were introduced to improve organizational coherence. They typically represent organizational structures such as regions, branches or divisions.',
        objectClass => ['organizationalUnit', 'top'],
        filter      => '(|(objectClass=organizationalUnit)(objectClass=organization))',
        attributes => { must => ['ou'], may => ['description'] },
        query =>
          { description => 'description of the organizational unit', dn => 'DN', ou => 'name of organizational unit' },
        default    => {},
        subentries => [['organizationalUnit', '*'], ['scLocation', '*'], ['scRefObjectContainer', '*']]
    },
    scHardware => {
        OID         => '1.3.6.1.4.1.7057.10.3.6.1.3',
        EID         => '2.16.840.1.113719.1.453.2.1.3',
        ATT         => ['STRUCTURAL'],
        mode        => 'admin',
        master      => ['cn'],
        DESC        => 'Reference to Standard PC hardware type and Server hardware',
        objectClass => ['scHardware', 'top'],
        filter      => '(objectClass=organization)',
        attributes  => {
            must => ['cn'],
            may  => [
                'scDhcpOptionsRemote', 'scPosImageDn',  'scPosDeltaImageDn', 'scRefPcDn',
                'scRefMonitorDn',      'scRefServerDn', 'scSUSEManager'
            ]
        },
        query => {
            cn                  => 'Common name of this object, first part of DN',
            dn                  => 'DN',
            scPosDeltaImageDn   => 'DN pointing to the standard Delta Image',
            scPosImageDn        => 'DN pointing to the standard Image',
            scDhcpOptionsRemote => 'default pxe code',
            scSUSEManager       => 'SUSE Manager address'

        },
        default             => {},
        subentries          => [],
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    scLocation => {
        OID    => '1.3.6.1.4.1.7057.10.3.6.1.12',
        EID    => '2.16.840.1.113719.1.453.2.1.12',
        ATT    => ['STRUCTURAL'],
        mode   => 'admin',
        master => ['ou', 'o'],
        DESC =>
'A branch office. This is a site where a Branch Server and Point of Service terminals are located. Location containers are used to store information about the deployed Point of Service terminals and the Branch Servers. This and all other information that can be modified at the Branch Server should be stored or referenced in the Location containers, to limit the need to grant write privileges to subtrees.',
        objectClass => ['scLocation', 'top'],
        filter      => '(|(objectClass=organizationalUnit)(objectClass=organization))',
        attributes  => {
            must => [
                'cn',                'ipNetworkNumber', 'ipNetmaskNumber', 'scDhcpRange',
                'scDhcpFixedRange',  'scDefaultGw',     'scDynamicIp',     'scWorkstationBaseName',
                'scEnumerationMask', 'scDhcpExtern',    'userPassword'
            ],
            may => [
                'scAllowRoles',      'scAllowGlobalRoles', 'scLdapDn',               'scDnsDn',
                'scPrinterBaseName', 'associatedDomain',   'scSynchronizedImagesDn', 'scIdPool',
                'scDnsMapFunc',      'scIpMapFunc',        'scLocked'
            ]
        },
        query => {
            associatedDomain   => 'DNS domain name',
            cn                 => 'Name of the Location or Branch',
            dn                 => 'DN',
            ipNetmaskNumber    => 'Local network mask',
            ipNetworkNumber    => 'Local network number',
            scDefaultGw        => 'Local network gateway',
            scDhcpExtern       => 'Use external DHCP Server (TRUE or FALSE, default FALSE)',
            scAllowRoles       => 'Allow rolebased functionality on this branch (TRUE or FALSE, default FALSE)',
            scAllowGlobalRoles => 'Allow global roles, i.e. roles above this scLocation (TRUE of FALSE, default FALSE)',
            scDhcpFixedRange   => 'Fixed IP range for workstations (from,to)',
            scDhcpRange        => 'Dynamic IP range for workstations (from,to)',
            scDynamicIp        => 'Allow dynamic IP addresses (TRUE or FALSE, default TRUE)',
            scEnumerationMask  => 'Mask for workstation enumeration (default 000)',
            scWorkstationBaseName => 'Basename for workstations (default CR)',
            userPassword          => 'Branch access password to central LDAP database and/or SUSE Manager',
            scSynchronizedImagesDn =>
              'DN of Image or CashRegister whose image is automatically synchronized from the Administration Server',
            scIdPool     => 'set of possible workstation IDs, if empty, ID functionality is disabled',
            scDnsMapFunc => 'DNS name mapping function',
            scIpMapFunc  => 'IP mapping function'
        },
        default => {
            scDhcpFixedRange      => '0.0.0.0,0.0.0.1',
            scDhcpRange           => '0.0.0.2,0.0.0.3',
            ipNetmaskNumber       => '0.0.0.0',
            ipNetworkNumber       => '0.0.0.0',
            scDefaultGw           => '0.0.0.0',
            scDhcpExtern          => 'FALSE',
            scDynamicIp           => 'TRUE',
            scAllowRoles          => 'FALSE',
            scAllowGlobalRoles    => 'FALSE',
            scEnumerationMask     => '000',
            scWorkstationBaseName => 'CR'
        },
        subentries => [
            ['scPxeFileTemplate',    '*'],
            ['scServerContainer',    '1'],
            ['scWorkstation',        '*'],
            ['scRefObjectContainer', '*']
        ],
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    scWorkstation => {
        OID => '1.3.6.1.4.1.7057.10.3.6.1.14',
        EID => '2.16.840.1.113719.1.453.2.1.14',
        DESC =>
'The Workstation object stores information for a specific Point of Service terminal. Using information from the Hardware Reference object (scCashRegister) and Image Reference object (scPosImage), posleases2ldap automatically creates a Workstation object in the LDAP directory for every Point of Service terminal that registers on the Branch Server.',
        ATT         => ['STRUCTURAL'],
        mode        => 'admin',
        master      => ['cn'],
        objectClass => ['scWorkstation', 'top'],
        filter      => '(objectClass=scLocation)',
        attributes  => {
            must => ['cn'],
            may  => [
                'macAddress',          'ipHostNumber',      'scSerialNumber',    'scRefPcDn',
                'scPosImageDn',        'scPosDeltaImageDn', 'scPosImageVersion', 'scPosRegisterBiosVersion',
                'scPosRegisterType',   'scId',              'scRoleDn',          'scConfigFileDn',
                'scStandardPrinterDn', 'userPassword',      'scStandardPrinter', 'scImageVersion',
                'scPosGroupDn',        'scDiskJournal',     'scConfigUpdate',    'scNotifiedImage',
                'scAllowedRolesDn',    'scRoleBased',       'scLastBootTime'
            ]
        },
        query => {
            cn                       => 'name of the workstation',
            dn                       => 'DN',
            ipHostNumber             => 'assigned IP address',
            macAddress               => 'MAC address(es)',
            scConfigFileDn           => 'DN of a configuration file',
            scPosDeltaImageDn        => 'associated Delta image DN',
            scPosGroupDn             => 'membership of a group',
            scPosImageDn             => 'associated Image DN',
            scPosImageVersion        => 'version of deployed image',
            scPosRegisterBiosVersion => 'bios Version of the workstation',
            scPosRegisterType        => 'hardware type of the workstation',
            scRefPcDn                => 'reference hardware',
            scRoleDn                 => 'DN of a role used to setup a given workstation',
            scId                     => 'ID of a workstation',
            scNotifiedImage =>
'Contains image and version, the time of notification, and md5sum of the associated config.MAC file separated by semicolons. It is updated when Point Of Service terminal boot with different image and/or configuration',
            scAllowedRolesDn => 'DN of roles allowed for this workstation',
            scRoleBased      => 'workstation registration mode indicator (used, e.g, for dumpall)'
        },
        default      => {},
        subentries   => [['scPxeFileTemplate', '*'], ['scConfigFileTemplate', '*'], ['scConfigFileSyncTemplate', '*']],
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        e_SUP        => 'top',
        e_X_NDS_CONTAINMENT => ['scLocation']
    },
    scServerContainer => {
        OID    => '1.3.6.1.4.1.7057.10.3.6.1.103',
        EID    => '2.16.840.1.113719.1.453.2.1.103',
        ATT    => ['STRUCTURAL'],
        mode   => 'admin',
        master => ['cn'],
        DESC =>
'A container for all the Branch Server objects for a given site. The information pertaining to the Branch Servers is stored in the Server container. To provide system redundancy and failover, there can be multiple Branch Servers for each site.',
        objectClass => ['scServerContainer', 'top'],
        filter      => '(objectClass=scLocation)',
        attributes => { must => ['cn'],                     may => [] },
        query      => { cn   => 'name of server container', dn  => 'DN' },
        default    => { cn   => 'server' },
        subentries          => [['scBranchServer', '1']],
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => ['scLocation']
    },
    scBranchServer => {
        OID    => '1.3.6.1.4.1.7057.10.3.6.1.25',
        EID    => '2.16.840.1.113719.1.453.2.1.25',
        ATT    => ['STRUCTURAL'],
        mode   => 'admin',
        master => ['cn'],
        DESC =>
'The Branch Server object stores configuration information that is specific to each Branch Server. There must be a Branch Server object for every Branch Server in the SUSE Linux Enterprise Point of Service system.',
        objectClass => ['scBranchServer', 'top'],
        filter      => '(objectClass=scServerContainer)',
        attributes => { must => ['cn'], may => ['scRefServerDn', 'scPubKey'] },
        query   => { cn => 'hostname of the server', description => 'description of the server', dn => 'DN' },
        default => {},
        subentries => [['scService', '+'], ['scNetworkcard', '+']],
        e_dn => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => ['scServerContainer']
    },
    scService => {
        OID         => '1.3.6.1.4.1.7057.10.3.6.1.2',
        EID         => '2.16.840.1.113719.1.453.2.1.2',
        ATT         => ['STRUCTURAL'],
        mode        => 'admin',
        master      => ['cn'],
        DESC        => 'The configuration for a Branch Server service like DNS, TFTP, or DHCP.',
        objectClass => ['scService', 'top'],
        filter      => '(objectClass=scBranchServer)',
        attributes  => {
            must => ['cn', 'scDnsName', 'scServiceName', 'scServiceStatus', 'scServiceStartScript'],
            may  => [
                'scServiceEmail',     'ipHostNumber',         'scDhcpDynLeaseTime', 'scDhcpFixedLeaseTime',
                'scPosleasesTimeout', 'scPosleasesChecktime', 'scPosleasesMaxNotify'
            ]
        },
        query => {
            cn                   => 'name of the service',
            dn                   => 'DN',
            ipHostNumber         => 'listening IP address for the service',
            scDnsName            => 'DNS name',
            scServiceName        => 'name of the service',
            scServiceStartScript => 'filename of the start script in /etc/init.d',
            scServiceStatus      => 'service enabled (TRUE or FALSE, default TRUE)',
            scPosleasesTimeout   => 'posleases2ldap specific, time spend on uploaded files checking',
            scPosleasesChecktime => 'posleases2ldap specific, pause before uploads checking',
            scPosleasesMaxNotify => 'posleases2ldap specific, maximum number of entries in scNotifiedImage',
            scDhcpDynLeaseTime   => 'dhcp specific, dynamic lease time for dhcp (1 <= n < 600)',
            scDhcpFixedLeaseTime => 'dhcp specific, fixed lease time for dhcp (>= 3600)'
        },
        default => { scServiceStatus => 'TRUE' },
        subentries          => [['scPxeFileTemplate', '*']],
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => ['scBranchServer']
    },
    scNetworkcard => {
        OID         => '1.3.6.1.4.1.7057.10.3.6.1.27',
        EID         => '2.16.840.1.113719.1.453.2.1.27',
        ATT         => ['STRUCTURAL'],
        mode        => 'admin',
        master      => ['cn'],
        DESC        => 'The configuration for a Branch Server network interface card.',
        objectClass => ['scNetworkcard', 'top'],
        filter      => '(|(objectClass=scCashRegister)(objectClass=scBranchServer))',
        attributes  => {
            must => ['scDevice',   'ipHostNumber'],
            may  => ['macAddress', 'scModul', 'scModulOption', 'ipNetmaskNumber']
        },
        query => {
            dn              => 'DN',
            ipHostNumber    => 'IP-Address',
            ipNetmaskNumber => 'Netmask',
            scDevice        => 'Network device',
            scModul         => 'Modulname',
            scModulOption   => 'Moduloptions'
        },
        default             => { scDevice => 'eth0', ipHostNumber => '0.0.0.0' },
        subentries          => [],
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => ['scBranchServer']
    },
    scRefObjectContainer => {
        OID    => '1.3.6.1.4.1.7057.10.3.6.1.104',
        ATT    => ['STRUCTURAL'],
        mode   => 'service',
        master => ['o'],
        DESC =>
'All globally valid information for a chain or company—that is server hardware, Point of Service hardware, or client images—is stored in the global container in the form of reference objects. These reference objects are linked to the actual entries for the Point of Service terminals and servers in the branches using distinguished names.',
        objectClass => ['scRefObjectContainer', 'top'],
        filter      => '|(objectClass=scLocation)(objectClass=organization)(objectClass=organizationalUnit)',
        attributes => { must => ['cn'], may => ['description'] },
        query   => { cn => 'Name for scRefObjectContainer', dn => 'DN', description => 'container description' },
        default => {},
        subentries => [['scCashRegister', '*'], ['scDistributionContainer', '*'], ['scRole', '*']]
    },
    scDistributionContainer => {
        OID    => '1.3.6.1.4.1.7057.10.3.6.1.107',
        EID    => '2.16.840.1.113719.1.453.2.1.107',
        ATT    => ['STRUCTURAL'],
        mode   => 'admin',
        master => ['cn'],
        DESC =>
'A distribution container is a collection of images designed for Point of Service terminals on a given version of the Linux kernel. The Default distribution container references the current kernel version included in SUSE Linux Enterprise Point of Service.',
        objectClass => ['scDistributionContainer', 'top'],
        filter      => '(objectClass=scRefObjectContainer)',
        attributes  => {
            must => ['cn',              'scKernelName',  'scInitrdName'],
            may  => ['scKernelVersion', 'scKernelMatch', 'scKernelExpression']
        },
        query => {
            cn                 => 'Common name of this object, from first part of DN',
            dn                 => 'DN',
            scInitrdName       => 'Filename of the initrd.gz placed in the /boot directory',
            scKernelExpression => 'Expression used to match the scKernelVersion string against uname',
            scKernelMatch =>
'Rule for matching scKernelVersion with the uname result. Valid: MATCH_VERSION, MATCH_ALL, MATCH_EXPRESSION',
            scKernelName    => 'Filename of the kernel placed in the /boot directory',
            scKernelVersion => 'Version string written to config file to indicate the version of this kernel'
        },
        default => { cn => 'default', scKernelName => 'linux', scInitrdName => 'initrd.gz' },
        subentries => [['scPxeFileTemplate', '*'], ['scPosImage', '+']],
        e_dn => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => ['scRefObjectContainer']
    },
    scPosImage => {
        OID    => '1.3.6.1.4.1.7057.10.3.6.1.30',
        EID    => '2.16.840.1.113719.1.453.2.1.30',
        ATT    => ['STRUCTURAL'],
        mode   => 'admin',
        master => ['cn'],
        DESC   => 'The Image Reference object stores information about an image stored on the Administration Server.',
        objectClass => ['scPosImage', 'top'],
        filter      => '(objectClass=scDistributionContainer)',
        attributes  => {
            must => ['cn', 'scImageName', 'scDhcpOptionsRemote', 'scDhcpOptionsLocal', 'scImageFile', 'scBsize'],
            may => ['scConfigFile', 'scPosImageVersion', 'scSUSEManagerChannel']
        },
        query => {
            cn                   => 'Common name of this object, from first part of DN',
            dn                   => 'DN',
            scBsize              => 'Blocksize depended of the file size, 1024, 2048,4096, 8192',
            scConfigFile         => 'List of config file with full path',
            scDhcpOptionsLocal   => 'DHPC Options for local Boot',
            scDhcpOptionsRemote  => 'DHPC Options for remote Boot',
            scImageFile          => 'Image File',
            scImageName          => 'Name of Image',
            scPosImageVersion    => 'List of Image Versions',
            scPassword           => 'Image password',
            scSUSEManagerChannel => 'name of SUSE Manager base channel under which terminal using this image registers'
        },
        default => { scDhcpOptionsRemote => '/boot/pxelinux.0', scDhcpOptionsLocal => 'LOCALBOOT', scBsize => '8192' },
        subentries => [
            ['scPxeFileTemplate',        '*'],
            ['scConfigFileTemplate',     '*'],
            ['scConfigFileSyncTemplate', '*'],
            ['scImageVersion',           '*']
        ],
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => ['scDistributionContainer']
    },
    scImageVersion => {
        OID         => '1.3.6.1.4.1.7057.10.3.6.1.110',
        EID         => '2.16.840.1.113719.1.453.2.1.110',
        ATT         => ['STRUCTURAL'],
        mode        => 'admin',
        master      => ['cn'],
        DESC        => 'Defines various image versions',
        objectClass => ['scImageVersion', 'top'],
        filter      => '(objectClass=scPosImage)',
        attributes  => { must => ['scVersion'], may => ['scDisabled', 'scPassword'] },
        query       => {
            dn         => 'DN',
            scPassword => 'Image password for this version',
            scVersion  => 'Image version (in x.y.z format)',
            scDisabled => 'disables this version usage if TRUE',
        },
        default             => { scDisabled => 'FALSE' },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => ['scPosImage']
    },
    scConfigFileSyncTemplate => {
        OID    => '1.3.6.1.4.1.7057.10.3.6.1.37',
        EID    => '2.16.840.1.113719.1.453.2.1.37',
        ATT    => ['STRUCTURAL'],
        mode   => 'admin',
        master => ['cn'],
        DESC =>
'scConfigFileSyncTemplate objects are used when you run services, such as X Windows, that require hardware-dependent configuration files. The scConfigFileSyncTemplate object points to the configuration file that a Point of Service terminal needs to run a given service. This object differs from scConfigFileTemplate objects because the configuration data is not stored in the object; rather, the object points to a configuration file outside the LDAP directory.',
        objectClass => ['scConfigFileSyncTemplate', 'top'],
        filter =>
          '(|(objectClass=scPosImage)(objectClass=scCashRegister)(objectClass=scWorkstation)(objectClass=scRole))',
        attributes => {
            must => ['cn',          'scMust', 'scConfigFile', 'scBsize', 'scConfigFileLocalPath'],
            may  => ['description', 'scConfigMd5']
        },
        query => {
            cn                    => 'Name of configuration file',
            dn                    => 'DN',
            scBsize               => 'Blocksize depended of the file size, 1024, 2048,4096, 8192',
            scConfigFile          => 'path of the config file on the cashregister',
            scConfigFileLocalPath => 'Local path to Configfile. Must be in rsync directory',
            scConfigMd5           => 'Md5sum of Configfile',
            scMust                => 'must or may configfile , TRUE | FALSE'
        },
        default      => { scMust => 'TRUE', scBsize => '8192' },
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        e_SUP        => 'top',
        e_X_NDS_CONTAINMENT => ['scPosImage', 'scCashRegister', 'scWorkstation', 'scRole']
    },
    scConfigFileTemplate => {
        OID         => '1.3.6.1.4.1.7057.10.3.6.1.32',
        EID         => '2.16.840.1.113719.1.453.2.1.32',
        ATT         => ['STRUCTURAL'],
        mode        => 'admin',
        master      => ['cn'],
        DESC        => 'Configuration File stored in LDAP',
        objectClass => ['scConfigFileTemplate', 'top'],
        filter =>
          '(|(objectClass=scPosImage)(objectClass=scCashRegister)(objectClass=scWorkstation)(objectClass=scRole))'
        ,    #SLEPOS11 sp1 added scWorkstation, scRole
        attributes => {
            must => ['cn',          'scMust',             'scConfigFile', 'scBsize', 'scConfigFileData'],
            may  => ['description', 'scConfigFileParser', 'scConfigMd5']
        },
        query => {
            cn                 => 'Name of configuration file',
            dn                 => 'DN',
            scBsize            => 'Blocksize depended of the file size, 1024, 2048,4096, 8192',
            scConfigFile       => 'path of the config file on the cashregister',
            scConfigFileData   => 'The Data of the configfile, this is the path to a local file',
            scConfigFileParser => 'Name of parserFunction to apply',
            scConfigMd5        => 'Md5sum of Configfile',
            scMust             => 'must or may configfile , TRUE | FALSE'
        },
        default      => { scMust => 'TRUE', scBsize => '8192' },
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        e_SUP        => 'top',
        e_X_NDS_CONTAINMENT => ['scPosImage', 'scCashRegister', 'scWorkstation', 'scRole']
    },
    scPxeFileTemplate => {
        OID         => '1.3.6.1.4.1.7057.10.3.6.1.108',
        EID         => '2.16.840.1.113719.1.453.2.1.108',
        ATT         => ['STRUCTURAL'],
        mode        => 'admin',
        master      => ['cn'],
        DESC        => 'PXE kernel parameters, stored in LDAP',
        objectClass => ['scPxeFileTemplate', 'top'],
        filter =>
'(|(objectClass=scPosImage)(objectClass=scCashRegister)(objectClass=scWorkstation)(objectClass=scRole)(objectClass=scDistributionContainer)(objectClass=scLocation)(objectClass=scService))'
        ,    #SLEPOS11 sp1 added scWorkstation, scRole
        attributes => { must => ['cn', 'scMust', 'scKernelParameters'], may => ['description'] },
        query      => {
            cn                 => 'Name of pxe template',
            dn                 => 'DN',
            scKernelParameters => 'kernel parameters to append',
            scMust             => 'must or may configfile , TRUE | FALSE'
        },
        default      => { scMust => 'TRUE' },
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        e_SUP        => 'top',
        e_X_NDS_CONTAINMENT => ['scPosImage', 'scCashRegister', 'scWorkstation', 'scRole']

    },
    scCashRegister => {
        OID         => '1.3.6.1.4.1.7057.10.3.6.1.31',
        EID         => '2.16.840.1.113719.1.453.2.1.31',
        ATT         => ['STRUCTURAL'],
        mode        => 'admin',
        master      => ['cn'],
        DESC        => 'The Hardware Reference object stores information about Point of Service hardware.',
        objectClass => ['scCashRegister', 'top'],
        filter      => '(|(objectClass=scRefObjectContainer)(objectClass=scRole))',
        attributes  => {
            must => ['cn',           'scCashRegisterName'],
            may  => ['scPosImageDn', 'scPosDeltaImageDn', 'scRaidScheme', 'scDiskJournal']
        },
        query => {
            cn                 => 'Common name of this object, from first part of DN',
            dn                 => 'DN',
            scCashRegisterName => 'Name of Type of this Cash Register',
            scPosDeltaImageDn  => 'DN pointing to the Delta Image associated with this Cash Register',
            scPosImageDn       => 'DN pointing to the Image associated with this Cash Register'
        },
        default    => {},
        subentries => [
            ['scHarddisk',               '*'],
            ['scRamDisk',                '*'],
            ['scPxeFileTemplate',        '*'],
            ['scConfigFileTemplate',     '*'],
            ['scConfigFileSyncTemplate', '*']
        ],
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => ['scRefObjectContainer', 'scRole']
    },
    scRamDisk => {
        OID          => '1.3.6.1.4.1.7057.10.3.6.1.33',
        EID          => '2.16.840.1.113719.1.453.2.1.33',
        ATT          => ['STRUCTURAL'],
        mode         => 'service',
        master       => ['cn'],
        DESC         => 'The configuration for a Point of Service terminal RAM disk.',
        objectClass  => ['scRamDisk', 'top'],
        filter       => '(objectClass=scCashRegister)',
        attributes   => { must => ['cn', 'scDevice'], may => [] },
        query        => { cn => 'Common Name', dn => 'DN', scDevice => 'Ramdiskdevice' },
        default      => {},
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        e_SUP        => 'top',
        e_X_NDS_CONTAINMENT => ['scCashRegister', 'scBranchServer']
    },
    scHarddisk => {
        OID         => '1.3.6.1.4.1.7057.10.3.6.1.26',
        EID         => '2.16.840.1.113719.1.453.2.1.26',
        ATT         => ['STRUCTURAL'],
        mode        => 'service',
        master      => ['cn'],
        DESC        => 'The configuration for a Point of Service terminal hard disk.',
        objectClass => ['scHarddisk', 'top'],
        filter      => '(|(objectClass=scCashRegister)(objectClass=scBranchServer))',
        attributes  => { must => ['cn', 'scDevice'], may => ['scPartitionsTable', 'scHdSize'] },
        query       => {
            cn                => 'Common Name',
            dn                => 'DN',
            scDevice          => 'Harddiskdevice',
            scHdSize          => 'Size of the harddisk',
            scPartitionsTable => 'Partiontable definition (may be deprecated, should be defined via scPartition object'
        },
        default             => {},
        subentries          => [['scPartition', '*']],
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => ['scBranchServer', 'scCashRegister']
    },
    scPartition => {
        OID         => '1.3.6.1.4.1.7057.10.3.6.1.111',
        EID         => '2.16.840.1.113719.1.453.2.1.111',
        ATT         => ['STRUCTURAL'],
        mode        => 'admin',
        master      => ['cn'],
        DESC        => 'Defintion of Potin of Service terminal hard disk partitioning',
        objectClass => ['scPartition', 'top'],
        filter      => '(objectClass=scHarddisk)',
        attributes =>
          { must => ['scPartNum', 'scPartType'], may => ['scPartMount', 'scPartSize', 'scPassword', 'description'] },
        query => {
            dn          => 'DN',
            scPartNum   => 'defines partition ordering',
            scPartType  => 'partition type ID',
            scPartSize  => 'partition size, in (binary) megabytes',
            scPartMount => 'partition mount point',
            scPassword  => 'image password for this partition',
            description => 'partition description',
        },
        default             => {},
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => ['scHarddisk']
    },
    scRole => {
        OID         => '1.3.6.1.4.1.7057.10.3.6.1.109',
        EID         => '2.16.840.1.113719.1.453.2.1.109',
        ATT         => ['STRUCTURAL'],
        mode        => 'admin',
        master      => ['cn'],
        DESC        => 'Contains role information, definition and all related data',
        objectClass => ['scRole', 'top'],
        filter      => '(objectClass=scRefObjectContainer)',
        attributes =>
          { must => ['cn', 'scRoleName'], may => ['scRoleDescription', 'scAllowedHwTypes', 'scDiskJournal'] },
        query => {
            cn                => 'Common name of this object, from first part of DN',
            dn                => 'DN',
            scRoleName        => 'Name of the role, as displayed during selection',
            scRoleDescription => 'More detailed description and information on the defined role',
            scAllowedHwTypes  => 'List of HWTYPE machine types allowed to see this role, all if empty.'
        },
        default    => {},
        subentries => [
            ['scConfigFileTemplate',     '*'],
            ['scPxeFileTemplate',        '*'],
            ['scConfigFileSyncTemplate', '*'],
            ['scCashRegister',           '*']
        ],
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => ['scRefObjectContainer', 'scLocation']
    },


    ###################################
    # FOLLOWING SEEMS TO BE OBSOLETED #
    ###################################
    #    scHAService => {
    #        OID         => '1.3.6.1.4.1.7057.10.3.6.1.28',
    #        EID         => '2.16.840.1.113719.1.453.2.1.28',
    #        DESC        => 'HA-Service of a BranchServerCluster',
    #        ATT         => ['STRUCTURAL'],
    #        mode        => 'admin',
    #        master      => ['cn'],
    #        explanation => 'a service like ldap, tftp which is in high available modus',
    #        objectClass => ['scHAService', 'top'],
    #        filter      => '(objectClass=scBranchServer)',
    #        attributes  => {
    #            must => [
    #                'cn',              'ipHostNumber',     'scDnsName', 'scServiceName',
    #                'scServiceStatus', 'scPrimaryService', 'scServiceStartScript'
    #            ],
    #            may => ['scServiceEmail']
    #        },
    #        query => {
    #            cn                   => 'Servicename',
    #            dn                   => 'DN',
    #            ipHostNumber         => 'IP-Address',
    #            scDnsName            => 'DNS name',
    #            scPrimaryService     => 'Primary service',
    #            scServiceName        => 'Name of the service',
    #            scServiceStartScript => 'Name of the start script in /etc/init.d',
    #            scServiceStatus      => 'Status of the Service'
    #        },
    #        default =>
    #          { cn => 'hostname', scPrimaryService => 'TRUE', scServiceName => 'hostname', scServiceStatus => 'TRUE' },
    #        e_dn                => 'cn=schema',
    #        e_changetype        => 'modify',
    #        e_SUP               => 'top',
    #        e_X_NDS_CONTAINMENT => ['scBranchServer']
    #    },
    #    scPosDeltaImage => {
    #        OID         => '1.3.6.1.4.1.7057.10.3.6.1.8',
    #        DESC        => 'Delta image for pos',
    #        ATT         => ['STRUCTURAL'],
    #        mode        => 'admin',
    #        master      => ['cn'],
    #        explanation => 'POS Software Delta Image',
    #        objectClass => ['scPosDeltaImage', 'top'],
    #        filter      => '(objectClass=scDistributionContainer)',
    #        attributes  => { must => ['cn', 'scImageName', 'scImageFile', 'scBsize'], may => [] },
    #        query       => {
    #            cn          => 'common name of this object, from first part of DN',
    #            dn          => 'DN',
    #            scBsize     => 'Blocksize depended of the file size, 1024, 2048,4096, 8192',
    #            scImageFile => 'Image File',
    #            scImageName => 'Name of Delta Image'
    #        },
    #        default => {}
    #    },
    #    scRefServer => {
    #        OID         => '1.3.6.1.4.1.7057.10.3.6.1.24',
    #        EID         => '2.16.840.1.113719.1.453.2.1.24',
    #        DESC        => 'description of a reference server',
    #        ATT         => ['STRUCTURAL'],
    #        mode        => 'service',
    #        master      => ['cn'],
    #        explanation => 'a reference Server for the global database',
    #        objectClass => ['scRefServer', 'top'],
    #        filter      => '(objectClass=scRefObjectContainer)',
    #        attributes  => {
    #            must => ['cn', 'scGraphicCard', 'scMouse', 'scRamSize', 'scCpuType', 'scKeyboard', 'scKbLayout'],
    #            may  => ['scController']
    #        },
    #        query => {
    #            cn            => 'Name of RefServer',
    #            dn            => 'DN',
    #            scController  => 'Controller',
    #            scCpuType     => 'Type of CPU',
    #            scGraphicCard => 'Graphiccard',
    #            scKbLayout    => 'Layout of Keyboard',
    #            scKeyboard    => 'Keyboard',
    #            scMouse       => 'Mousetype',
    #            scRamSize     => 'RAM size'
    #        },
    #        default             => {},
    #        e_dn                => 'cn=schema',
    #        e_changetype        => 'modify',
    #        e_SUP               => 'top',
    #        e_X_NDS_CONTAINMENT => []
    #    },
    #    scPosUser => {
    #        OID                 => '1.3.6.1.4.1.7057.10.3.6.1.36',
    #        EID                 => '2.16.840.1.113719.1.453.2.1.36',
    #        DESC                => 'Account for a User in a Branch',
    #        ATT                 => ['STRUCTURAL'],
    #        mode                => 'admin',
    #        master              => ['cn'],
    #        explanation         => 'Account of a branch',
    #        objectClass         => ['scPosUser', 'top'],
    #        filter              => '(objectClass=scLocation)',
    #        attributes          => { must => ['cn', 'userPassword'], may => ['description'] },
    #        query               => { cn => 'Name of the user', dn => 'DN', userPassword => 'Password' },
    #        default             => {},
    #        e_dn                => 'cn=schema',
    #        e_changetype        => 'modify',
    #        e_SUP               => 'top',
    #        e_X_NDS_CONTAINMENT => []
    #    },
);


############################################
# eDir objects hash:
# used to generate edir.schema
#  contains objects which are
#  in eDir only
#  in LDAP and eDir but different
############################################
%EDIR_STRUCT = (
    scServer => {
        EID        => '2.16.840.1.113719.1.453.2.1.1',
        DESC       => 'Physical server',
        ATT        => ['AUXILIARY'],
        attributes => { must => ['macAddress', 'ipHostNumber', 'scDnsName', 'ipServiceProtocol'], may => ['scPubKey'] },
        e_dn       => 'cn=schema',
        e_changetype        => 'modify',
        e_X_NDS_CONTAINMENT => []
    },
    scBandWidth => {
        EID  => '2.16.840.1.113719.1.453.2.1.4',
        DESC => 'Attributes for bandwidthmanagement',
        ATT  => ['AUXILIARY'],
        attributes =>
          { must => ['scLanBandWidth', 'scWanBandWidth', 'scBandWidthLimitLan', 'scBandWidthLimitWan'], may => [] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_X_NDS_CONTAINMENT => []
    },
    scRefPc => {
        EID        => '2.16.840.1.113719.1.453.2.1.5',
        DESC       => 'Hardware-description for pc',
        ATT        => ['STRUCTURAL'],
        attributes => {
            must => [
                'CN',                  'scGraphicCard',      'scNic',      'scRamSize',
                'scCpuType',           'scMouse',            'scKeyboard', 'scKbLayout',
                'scDhcpOptionsRemote', 'scDhcpOptionsLocal', 'scRefImageDn'
            ],
            may => []
        },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    scRefMonitor => {
        EID                 => '2.16.840.1.113719.1.453.2.1.6',
        DESC                => 'Hardware-description for different monitors',
        ATT                 => ['AUXILIARY'],
        attributes          => { must => ['scHsync', 'scVsync', 'scMonitorRes', 'scDefaultRes'], may => [] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_X_NDS_CONTAINMENT => []
    },
    scRefPrinter => {
        EID        => '2.16.840.1.113719.1.453.2.1.7',
        DESC       => 'Hardware-description for different printers',
        ATT        => ['AUXILIARY'],
        attributes => {
            must => ['scPrinterLanguage', 'scDrivername', 'scPpd', 'scPrinterDeviceUri'],
            may  => ['scPrinterDeviceUriOptional']
        },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_X_NDS_CONTAINMENT => []
    },
    scRefDeltaImage => {
        EID                 => '2.16.840.1.113719.1.453.2.1.8',
        DESC                => 'Definitions of delta images',
        ATT                 => ['AUXILIARY'],
        attributes          => { must => ['scImageLocation', 'scImageVersion', 'scImageSize'], may => [] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_X_NDS_CONTAINMENT => []
    },
    scRefImage => {
        EID        => '2.16.840.1.113719.1.453.2.1.9',
        DESC       => 'Definitions of images',
        ATT        => ['AUXILIARY'],
        attributes => {
            must => [
                'scPartitionsTable', 'scInitRdScript', 'scExcludeList', 'scImageLocation',
                'scImageVersion',    'scImageSize'
            ],
            may => ['scExcludeListRunning']
        },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_X_NDS_CONTAINMENT => []
    },
    scInventory => {
        EID                 => '2.16.840.1.113719.1.453.2.1.16',
        DESC                => 'Inventory of hardware',
        ATT                 => ['AUXILIARY'],
        attributes          => { must => [], may => ['scPcibus', 'scCpuInfo', 'scHdSize'] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_X_NDS_CONTAINMENT => []
    },
    scPrinter => {
        EID                 => '2.16.840.1.113719.1.453.2.1.17',
        DESC                => 'The real printers in a location',
        ATT                 => ['AUXILIARY'],
        attributes          => { must => ['scRefPrinterDn', 'scDnsName'], may => ['macAddress', 'ipServicePort'] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_X_NDS_CONTAINMENT => []
    },
    scTokenRing => {
        EID          => '2.16.840.1.113719.1.453.2.1.22',
        DESC         => 'objectClass for determining Token-Ring workstation, normally used together with scWorkstation',
        ATT          => ['AUXILIARY'],
        attributes   => { must => [], may => ['macAddress'] },
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        e_X_NDS_CONTAINMENT => []
    },
    scBootConfig => {
        EID                 => '2.16.840.1.113719.1.453.2.1.23',
        DESC                => 'config file for booting',
        ATT                 => ['AUXILIARY'],
        attributes          => { must => ['CN', 'scBootConfigFileName', 'scStartOption'], may => ['Description'] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_X_NDS_CONTAINMENT => []
    },
    scStandardServices => {
        EID                 => '2.16.840.1.113719.1.453.2.1.29',
        DESC                => 'Standardservices like ldap and DNS-Master outsite the branch scope',
        ATT                 => ['STRUCTURAL'],
        attributes          => { must => ['CN'], may => ['scLdapDn', 'scDnsDn'] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    scPosImageSync => {
        EID                 => '2.16.840.1.113719.1.453.2.1.34',
        DESC                => 'Image for pos',
        ATT                 => ['STRUCTURAL'],
        attributes          => { must => ['scImageName', 'scPosImageVersion'], may => ['scPosImageDefaultVersion'] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    scPosGroup => {
        EID                 => '2.16.840.1.113719.1.453.2.1.35',
        DESC                => 'blank',
        ATT                 => ['STRUCTURAL'],
        attributes          => { must => ['CN'], may => ['Description'] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    scRegion => {
        EID                 => '2.16.840.1.113719.1.453.2.1.102',
        DESC                => 'SmartClient region marker',
        ATT                 => ['STRUCTURAL'],
        attributes          => { must => ['CN'], may => [] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    scUserContainer => {
        EID                 => '2.16.840.1.113719.1.453.2.1.105',
        DESC                => 'SmartClient user container',
        ATT                 => ['STRUCTURAL'],
        attributes          => { must => ['CN'], may => [] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    scUserGroupContainer => {
        EID                 => '2.16.840.1.113719.1.453.2.1.106',
        DESC                => 'SmartClient user group container',
        ATT                 => ['AUXILIARY'],
        attributes          => { must => [], may => [] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    ipService => {
        EID => '2.16.840.1.113719.1.453.2.1.200',
        DESC =>
'Abstraction an Internet Protocol service. Maps an IP port and protocol (such as tcp or udp) to one or more names; the distinguished value of the cn attribute denotes the services canonical name',
        ATT                 => ['STRUCTURAL'],
        attributes          => { must => ['cn', 'ipServicePort', 'ipServiceProtocol'], may => ['Description'] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    ipProtocol => {
        EID => '2.16.840.1.113719.1.453.2.1.201',
        DESC =>
'Abstraction of an IP protocol. Maps a protocol number to one or more names. The distinguished value of the cn attribute denotes the protocols canonical name',
        ATT                 => ['STRUCTURAL'],
        attributes          => { must => ['cn', 'ipProtocolNumber'], may => ['Description'] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    oncRpc => {
        EID => '2.16.840.1.113719.1.453.2.1.202',
        DESC =>
'Abstraction of an Open Network Computing (ONC) [RFC1057] Remote Procedure Call (RPC) binding. This class maps an ONC RPC number to a name. The distinguished value of the cn attribute denotes the RPC services canonical name',
        ATT                 => ['STRUCTURAL'],
        attributes          => { must => ['cn', 'oncRpcNumber'], may => ['Description'] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    ipHost => {
        EID => '2.16.840.1.113719.1.453.2.1.203',
        DESC =>
'Abstraction of a host, an IP device. The distinguished value of the cn attribute denotes the hosts canonical name. Device SHOULD be used as a structural class',
        ATT          => ['AUXILIARY'],
        attributes   => { must => ['cn', 'ipHostNumber'], may => ['userPassword', 'l', 'Description', 'manager'] },
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        e_SUP        => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    ipNetwork => {
        EID => '2.16.840.1.113719.1.453.2.1.204',
        DESC =>
          'Abstraction of a network. The distinguished value of the cn attribute denotes the networks canonical name',
        ATT        => ['STRUCTURAL'],
        attributes => { must => ['ipNetworkNumber'], may => ['cn', 'ipNetmaskNumber', 'l', 'Description', 'manager'] },
        e_dn       => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    nisNetgroup => {
        EID                 => '2.16.840.1.113719.1.453.2.1.205',
        DESC                => 'Abstraction of a netgroup. May refer to other netgroups',
        ATT                 => ['STRUCTURAL'],
        attributes          => { must => ['cn'], may => ['nisNetgroupTriple', 'memberNisNetgroup', 'Description'] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    nisMap => {
        EID                 => '2.16.840.1.113719.1.453.2.1.206',
        DESC                => 'A generic abstraction of a NIS map',
        ATT                 => ['STRUCTURAL'],
        attributes          => { must => ['nisMapName'], may => ['Description'] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    nisObject => {
        EID                 => '2.16.840.1.113719.1.453.2.1.207',
        DESC                => 'An entry in a NIS map',
        ATT                 => ['STRUCTURAL'],
        attributes          => { must => ['cn', 'nisMapEntry', 'nisMapName'], may => ['Description'] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    ieee802Device => {
        EID                 => '2.16.840.1.113719.1.453.2.1.208',
        DESC                => 'A device with a MAC address; device SHOULD be used as a structural class',
        ATT                 => ['AUXILIARY'],
        attributes          => { must => [], may => ['macAddress'] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    bootableDevice => {
        EID                 => '2.16.840.1.113719.1.453.2.1.209',
        DESC                => 'A device with boot parameters; device SHOULD be used as a structural class',
        ATT                 => ['AUXILIARY'],
        attributes          => { must => [], may => ['bootFile', 'bootParameter'] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    nisKeyObject => {
        EID                 => '2.16.840.1.113719.1.453.2.1.210',
        DESC                => 'An object with a public and secret key',
        ATT                 => ['AUXILIARY'],
        attributes          => { must => ['cn', 'nisPublicKey', 'nisSecretKey'], may => ['uidNumber', 'Description'] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    nisDomainObject => {
        EID                 => '2.16.840.1.113719.1.453.2.1.211',
        DESC                => 'Associates a NIS domain with a naming context',
        ATT                 => ['AUXILIARY'],
        attributes          => { must => ['nisDomain'], may => [] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    automountMap => {
        EID                 => '2.16.840.1.113719.1.453.2.1.212',
        ATT                 => ['STRUCTURAL'],
        attributes          => { must => ['automountMapName'], may => ['Description'] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    automount => {
        EID                 => '2.16.840.1.113719.1.453.2.1.213',
        DESC                => 'Automount information',
        ATT                 => ['STRUCTURAL'],
        attributes          => { must => ['automountKey', 'automountInformation'], may => ['Description'] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    },
    namedObject => {
        EID                 => '2.16.840.1.113719.1.453.2.1.214',
        ATT                 => ['STRUCTURAL'],
        attributes          => { must => [], may => ['cn'] },
        e_dn                => 'cn=schema',
        e_changetype        => 'modify',
        e_SUP               => 'top',
        e_X_NDS_CONTAINMENT => []
    }
);


############################################
# ldap attributes hash:
# used to generate sc-pos.attr.schema, edir.schema, SLEPOS doc and XML validation template
#  contains attributes which are
#  in orig LDAP only
#  in orig LDAP and eDir and same
#  in orig LDAP and eDir and differing
# format:
# attributeName => {
# 	OID  => LDAP ID of attribute
#   EID  => EDIR ID of attribute
#   DESC => description, visible in help and documentation
#   EQUALITY => LDAP equality checking func
#   SYNTAX => LDAP data type
#   e_dn   => ? something for eDir
#   e_changetype => ? something for eDir
#   data_type => XML data type, can be any of following:
#     boolean, ip, unsignedInt(min,max), enum("values",...), string("regexp"), dn, unsignedShort(min,max), mac, |
#      if absend, string without pattern is assumed
#      | means or
#      except enum, values in () are optional
#      ip,ip is exception and means two IPs separated by ,
#     for details see POS::Ldap2XML module
# }
############################################
%LDAP_ATTR_STRUCT = (
    scDefaultGw => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.6',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.6',
        DESC =>
          'IP address of default gateway for location. This is normally a router to the corporate wide area network.',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26{128}',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'ip'
    },
    scDhcpFixedRange => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.10',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.10',
        DESC =>
'The fixed IP address range of the DHCP server reserved for the Point of Service terminals. Comma-separated value pair, e.g. 192.168.1.55, 192.168.1.88.',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'ip,ip'
    },
    scDhcpRange => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.11',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.11',
        DESC =>
'The dynamic IP address range of the DHCP server. This is needed to register the Point of Service terminals. Comma-separated value pair, e.g. 192.168.1.10, 192.168.1.54.',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'ip,ip'
    },
    scDnsName => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.12',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.12',
        DESC         => 'The name of entry in the DNS table under which the service is available.',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scDynamicIp => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.17',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.17',
        DESC =>
'Enable or disable registration of new terminals on the Branch Server when scDhcpExtern is set to FALSE. (TRUE or FALSE, default TRUE)',
        EQUALITY     => 'booleanMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'boolean'
    },
    scHdSize => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.21',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.21',
        DESC         => 'Size of the hard disk in MB',
        EQUALITY     => 'integerMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'unsignedInt'
    },
    scImageVersion => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.26',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.26',
        DESC         => 'Image version in format yyyymmddserial',
        EQUALITY     => 'integerMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        DEPRECATED   => '1'
    },
    scRefMonitorDn => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.34',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.34',
        DESC         => 'DN of monitor type',
        EQUALITY     => 'distinguishedNameMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scPartitionsTable => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.37',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.37',
        DESC =>
'A semicolon-separated (;) list of partition entries. Each entry consists of three space-separated parameters: the size in megabytes, the partition type ID (82 or S for swap, 83 or L for a Linux partition), and the mount point. If the mountpoint equals /, the partition is assumed to be the root partition, and x means no mountpoint (for example for swap). For the last partition, size can be specified as x which results in all remaining available space to be used.',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        DEPRECATED   => 'scPartition',
        data_type    => 'string(([0-9]+ [a-z0-9]+ [^;]+( [^;]+)*;)*[0-9x]+ [a-z0-9]+ [^;]+( [^;]+)*;?)'
    },
    scPubKey => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.41',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.41',
        DESC         => 'Public key stored at server for the SSH client',
        EQUALITY     => 'caseExactIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scRefPcDn => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.44',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.44',
        DESC         => 'DN to PC hardware type',
        EQUALITY     => 'distinguishedNameMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scServiceEmail => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.49',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.49',
        DESC         => 'Where should the service send an e-mail to',
        EQUALITY     => 'caseIgnoreIA5Match',
        SUBSTR       => 'caseIgnoreIA5SubstringsMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26{256}',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scStandardPrinterDn => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.51',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.51',
        DESC         => 'DN of the standard printer for a location or workstation',
        EQUALITY     => 'distinguishedNameMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        DEPRECATED   => '1'
    },
    scServiceStatus => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.52',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.52',
        DESC         => 'Enable service (TRUE or FALSE, default TRUE)',
        EQUALITY     => 'booleanMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'boolean'
    },
    scSerialNumber => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.55',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.55',
        DESC         => 'Serial number of the used workstation',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        DEPRECATED   => '1'
    },
    scServiceName => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.56',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.56',
        DESC         => 'Name of the service. Supported services are dns, dhcp, tftp, ftp and posleases.',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scDhcpOptionsRemote => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.57',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.57',
        DESC         => 'The boot option of the Point of Service terminal. The mandatory value is /boot/pxelinux.0',
        EQUALITY     => 'caseExactIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'enum(/boot/pxelinux.0)'
    },
    scDhcpOptionsLocal => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.58',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.58',
        DESC         => 'Additional DHCP options for local boot',
        EQUALITY     => 'caseExactIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scStandardPrinter => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.72',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.72',
        DESC         => 'Name of the standard printer',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        DEPRECATED   => '1'
    },
    scDevice => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.80',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.80',
        DESC         => 'The name of the device. E.g. eth0 /dev/hda /dev/hda1 ...',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scModul => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.81',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.81',
        DESC         => 'The name of the Linux kernel module for the network interface card.',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        DEPRECATED   => '1',
    },
    scModulOption => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.82',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.82',
        DESC         => 'The module options for the network interface card to be passed to the kernel',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        DEPRECATED   => '1',
    },
    scRefServerDn => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.85',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.85',
        DESC         => 'DN of a scRefServer',
        EQUALITY     => 'distinguishedNameMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scLdapDn => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.86',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.86',
        DESC         => 'DN of a scRefServer',
        EQUALITY     => 'distinguishedNameMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.12',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scDnsDn => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.87',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.87',
        DESC         => 'DN of a scRefServer',
        EQUALITY     => 'distinguishedNameMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.12',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scImageFile => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.89',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.89',
        DESC         => 'File name of the image. e.g. minimal.arch',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scConfigFile => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.90',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.90',
        DESC         => 'File name of configuration file',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scImageName => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.91',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.91',
        DESC         => 'The name of the image; for example, minimal',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scWorkstationBaseName => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.92',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.92',
        DESC =>
'The base name of the Point of Service terminals to create a unique name for each terminal. Used in combination with the scDhcpFixedRange attribute and scEnumerationMask (default CR)',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scPrinterBaseName => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.93',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.93',
        DESC =>
'The base name of the Point of Service printers to create a unique name for each printer. It is used in combination with the scDhcpFixedRange attribute and scEnumerationMask.',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        DEPRECATED   => '1'
    },
    scEnumerationMask => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.94',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.94',
        DESC         => 'Enumaration mask for Point Of Service terminals and printers, e.g. 000 or 00 (default 000)',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'string(0+)'
    },
    scCashRegisterName => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.95',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.95',
        DESC =>
'The model type of the Point of Service terminal. If this field is set to "default", the current scCashRegister object is used as the default Point of Service configuration. If a Point of Service terminal does not have an scCashRegister object for its specific hardware type, it will use the configuration defined in the default scCashRegister object',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scPosImageDn => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.96',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.96',
        DESC         => 'The DN of the default system image defined for this Point of Service terminal type',
        EQUALITY     => 'distinguishedNameMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'dn'
    },
    scPosImageVersion => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.97',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.97',
        DESC =>
'The version number of the system image, followed by the flag passive or active; i.e., 2.0.4; active. The version number and the flag are semicolon-separated (;)',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        DEPRECATED   => 'scImageVersion',
    },
    scBsize => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.98',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.98',
        DESC =>
'Block size for the TFTP download of the system image. Minimum 4096 for image size up to 128MB, maximum 65464 for image size up to 4GB',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'unsignedShort(512,65464)'
    },
    scMust => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.99',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.99',
        DESC         => 'Enable or disable the configuration file. (TRUE or FALSE)',
        EQUALITY     => 'booleanMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'boolean'
    },
    scConfigFileData => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.100',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.100',
        DESC         => 'Content of the configuration file, automatically filled by posAdmin',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scConfigFileParser => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.101',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.101',
        DESC         => 'Name of parserFunction to apply',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scPosRegisterBiosVersion => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.103',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.103',
        DESC         => 'BIOS version of a Point Of Service terminal',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scPosGroupDn => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.104',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.104',
        DESC         => 'DN of a CR group.',
        EQUALITY     => 'distinguishedNameMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.12',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        DEPRECATED   => '1'
    },
    scServiceStartScript => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.105',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.105',
        DESC         => 'Filename of the init script in /etc/init.d',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scConfigFileDn => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.106',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.106',
        DESC =>
'Reference for a configuration type object (scConfigFileTemplate, scConfigFileSyncTemplate, scPxeFileTemplate)',
        EQUALITY     => 'distinguishedNameMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.12',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scConfigFileLocalPath => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.107',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.107',
        DESC =>
'The local source path of the configuration file on the Administration Server. For example, /srv/SLEPOS/config/X11/xorg.conf.mydata. This path must be located in the rsync directory',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scConfigMd5 => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.109',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.109',
        DESC         => 'The MD5 checksum value of the configuration file, automatically generated by posAdmin',
        EQUALITY     => 'caseExactIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scDiskJournal => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.110',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.110',
        DESC         => 'Turn on disk journaling. This will only occur on diskfull systems. (TRUE or FALSE)',
        EQUALITY     => 'booleanMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'boolean'
    },
    scConfigUpdate => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.111',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.111',
        DESC         => 'Indicate configuration files should be updated on the next boot. (TRUE or FALSE)',
        EQUALITY     => 'booleanMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'boolean'
    },
    scKernelName => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.112',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.112',
        DESC         => 'Filename of the kernel placed in the /boot directory',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scInitrdName => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.113',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.113',
        DESC         => 'Filename of the initrd.gz placed in the /boot directory',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scKernelVersion => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.114',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.114',
        DESC         => 'Version string written to config file to indicate the version of this kernel',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scKernelMatch => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.115',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.115',
        DESC =>
'Rule for matching scKernelVersion with the uname result. Valid are MATCH_VERSION, MATCH_ALL, MATCH_EXPRESSION',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scKernelExpression => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.116',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.116',
        DESC         => 'Expression used to match the scKernelVersion string against uname',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scNotifiedImage => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.117',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.117',
        DESC =>
'Contains image and version, the time of notification, and md5sum of the associated config.MAC file separated by semicolons. It is updated when Point Of Service terminal boot with different image and/or configuration',
        EQUALITY     => 'caseIgnoreIA5Match',
        SUBSTR       => 'caseIgnoreIA5SubstringsMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scPosDeltaImageDn => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.118',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.118',
        DESC         => 'DN of delta image for a Point Of Service terminal',
        EQUALITY     => 'distinguishedNameMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.12',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        DEPRECATED   => '1'
    },
    scDhcpExtern => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.119',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.119',
        DESC =>
'Allow an external DHCP server to be used instead of setting up own on the Branch Server (TRUE or FALSE, default FALSE)',
        EQUALITY     => 'booleanMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'boolean'
    },
    scPosRegisterType => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.120',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.120',
        DESC         => 'Cash Register type associated with Point Of Service terminal',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scKernelParameters => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.121',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.121',
        DESC         => 'Kernel parameters to append, to use in a custom pxe boot file',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scSynchronizedImagesDn => {
        OID  => '1.3.6.1.4.1.7057.10.3.4.1.122',
        EID  => '2.16.840.1.113719.1.453.1.1.1.1.1.122',
        DESC => 'DN of Image or CashRegister whose image is automatically synchronized from the Administration Server',
        EQUALITY     => 'distinguishedNameMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.12',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
    },
    scRoleName => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.123',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.123',
        DESC         => 'Name of the role. Displayed in the list on the Point Of Service terminal',
        EQUALITY     => 'caseExactMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scRoleDescription => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.124',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.124',
        DESC         => 'Description of the role. Displayed in the list on the Point Of Service terminal',
        EQUALITY     => 'caseExactMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.15',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scIdPool => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.125',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.125',
        DESC         => 'Set of possible Point Of Service terminal IDs',
        EQUALITY     => 'caseExactMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.15',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scRoleDn => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.126',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.126',
        DESC         => 'DN of the role assigned to the Point Of Service terminal',
        EQUALITY     => 'distinguishedNameMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.12',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'dn'
    },
    scId => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.127',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.127',
        DESC         => 'Contains ID assigned to the Point Of Service terminal',
        EQUALITY     => 'caseExactMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.15',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scAllowRoles => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.128',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.128',
        DESC =>
'If TRUE and scAllowGlobalRoles is TRUE, the role-based mode and all roles are enabled. If TRUE and scAllowGlobalRoles is FALSE, the role-based mode is enabled, but only roles under this branch are used. If FALSE, roles are not enabled. (TRUE or FALSE, FALSE)',
        EQUALITY     => 'booleanMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'boolean'
    },
    scAllowGlobalRoles => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.129',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.129',
        DESC         => 'Allow roles outside of this branch. (TRUE or FALSE, default FALSE)',
        EQUALITY     => 'booleanMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'boolean'
    },
    scAllowedRolesDn => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.130',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.130',
        DESC         => 'DNs of allowed roles. If empty, all roles are permitted',
        EQUALITY     => 'distinguishedNameMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.12',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scAllowedHwTypes => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.131',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.131',
        DESC         => 'Allow role to be used only with given hardware types',
        EQUALITY     => 'caseExactIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scRoleBased => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.132',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.132',
        DESC         => 'The Point Of Service terminal use roles. (TRUE or FALSE)',
        EQUALITY     => 'booleanMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'boolean'
    },
    scRaidScheme => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.133',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.133',
        DESC =>
'Definition of RAID. Only RAID type 1 is supported. The format of the entry is: 1 disk1 disk2. The disks can be specified by name (/dev/sda) or by id (/dev/disk/by-id/ata-ST3160815AS_Z4A1ATWL). The values are separated by spaces',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scDnsMapFunc => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.134',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.134',
        DESC         => 'DNS mapping function (NONE | DIRECT | TRANSFORM:regexp)',
        EQUALITY     => 'caseExactMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.15',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type =>
          'string([nN][oO][nN][eE])|string([dD][iI][rR][eE][cC][tT])|string([tT][rR][aA][nN][sS][fF][oO][rR][mM]:.+)'
    },
    scIpMapFunc => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.135',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.135',
        DESC         => 'IP mapping function (NONE | DIRECT | TRANSFORM:regexp)',
        EQUALITY     => 'caseExactMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.15',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type =>
          'string([nN][oO][nN][eE])|string([dD][iI][rR][eE][cC][tT])|string([tT][rR][aA][nN][sS][fF][oO][rR][mM]:.+)'
    },
    scLocked => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.136',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.136',
        DESC         => '0 or time when DB was locked, is set by SLEPOS tools, DO NOT set manually',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        DEPRECATED   => '1'
    },
    scDhcpDynLeaseTime => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.137',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.137',
        DESC         => 'DHCP service specific. Lease time for dynamic leases (first boot) (default 300)',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'unsignedShort'
    },
    scDhcpFixedLeaseTime => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.138',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.138',
        DESC         => 'DHCP service specific. Lease time for fixed leases (final registration) (default 14400)',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'unsignedShort'
    },
    scPosleasesTimeout => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.139',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.139',
        DESC         => 'posleases service specific. How often should posleases2ldap update internal cache. (seconds)',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'unsignedShort'
    },
    scPosleasesChecktime => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.140',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.140',
        DESC =>
          'posleases service specific. For how long should posleases2ldap pause before checking uploads. (seconds)',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'unsignedShort'
    },
    scPosleasesMaxNotify => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.141',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.141',
        DESC =>
'posleases service specific. Maximum number of booted image notifications (maximum of scNotifiedImage entries)',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'unsignedShort'
    },
    scPassword => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.142',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.142',
        DESC =>
'Image or partition password. In case of partition password * means random password will be generated each boot. Userful for swap partitions',
        EQUALITY     => 'caseExactIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scDisabled => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.143',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.143',
        DESC         => 'Enables or disables this version for registration. (TRUE or FALSE)',
        EQUALITY     => 'booleanMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'boolean'
    },
    scVersion => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.144',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.144',
        DESC         => 'Image version number (x.y.z format)',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scPartNum => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.145',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.145',
        DESC =>
'Defines the order of partitions (not the partition number shown by fdisk, the real partiton number is determined by KIWI during terminal boot)',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'unsignedShort'
    },
    scPartType => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.146',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.146',
        DESC         => 'The type of partition (82 or S for swap, 83 or L for a Linux partition)',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scPartMount => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.147',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.147',
        DESC =>
'The mount point of the partition. Use / for the root partition. Use x for a partition without a mountpoint (for example a swap partition)',
        EQUALITY     => 'caseExactIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scPartSize => {
        OID => '1.3.6.1.4.1.7057.10.3.4.1.148',
        EID => '2.16.840.1.113719.1.453.1.1.1.1.1.148',
        DESC =>
'Size of partition in (binary) megabytes. For the last partition, size can be specified as x, which results in all remaining available space to be used',
        EQUALITY     => 'caseExactIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'unsignedInt|enum(x)'
    },
    macAddress => {    #not to generate pos schema, just to allow posAdmin to understand this attribute
        DESC         => 'MAC address in maximal, colon separated hex notation, eg. 00:00:92:90:EE:F2',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'mac'
    },
    scSUSEManager => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.149',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.149',
        DESC         => 'SUSE Manager address (FQDN/ip address)',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    scLastBootTime => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.150',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.150',
        DESC         => 'Linux time of last time when terminal boot was detected by Branch Server',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify',
        data_type    => 'unsignedInt'
    },
    scSUSEManagerChannel => {
        OID          => '1.3.6.1.4.1.7057.10.3.4.1.151',
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.151',
        DESC         => 'name of SUSE Manager base channel under which terminal using this image registers',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },

    ########################################################
    # attributes below are defined in obsoleted objects    #
    ########################################################
    #    scCpuType => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.5',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.5',
    #        DESC         => 'eg. i686',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scGraphicCard => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.20',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.20',
    #        DESC         => 'Modulname, eg. nvidia',
    #        EQUALITY     => 'caseExactIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scKbLayout => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.27',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.27',
    #        DESC         => 'Keyboardlayout, eg. de | us',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scKeyboard => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.28',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.28',
    #        DESC         => 'eg. pc104',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scMouse => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.35',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.35',
    #        DESC         => 'Mousetype, eg. ps2 | microsoft',
    #        EQUALITY     => 'caseExactIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scRamSize => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.42',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.42',
    #        DESC         => 'Ramsize',
    #        EQUALITY     => 'integerMatch',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scPrimaryService => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.79',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.79',
    #        DESC         => 'Boolen Ha-Service true or false',
    #        EQUALITY     => 'booleanMatch',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scController => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.84',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.84',
    #        DESC         => 'Controller Modul',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },

    ########################################################
    # attributes below are not defined anywhere in objects #
    ########################################################
    #    scAuthorName => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.1',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.1',
    #        DESC         => 'Owner of last modification',
    #        EQUALITY     => 'caseIgnoreMatch',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scBandWidthLimitLan => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.2',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.2',
    #        DESC         => 'Two numeric fields, seperated by comma',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scBandWidthLimitWan => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.3',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.3',
    #        DESC         => 'Two numeric fields, seperated by comma',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scCachingImageServer => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.4',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.4',
    #        DESC         => 'Flag',
    #        EQUALITY     => 'booleanMatch',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scDefaultRes => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.7',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.7',
    #        DESC         => 'Two numeric fields, seperated by comma',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scDoRsync => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.13',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.13',
    #        DESC         => 'Flag: lan | wan | name | none',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scDoTftpBoot => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.14',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.14',
    #        DESC         => 'Flag: lan | wan | name | LOCALBOOT',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scUpdateTime => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.15',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.15',
    #        DESC         => 'Flag: now | time | difftime',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scExcludeList => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.19',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.19',
    #        DESC         => 'List of pathes',
    #        EQUALITY     => 'caseExactIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scHsync => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.22',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.22',
    #        DESC         => 'Two numeric fields, seperated by comma',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scImageLocation => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.25',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.25',
    #        DESC         => 'Path to image',
    #        EQUALITY     => 'caseExactIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scLanBandWidth => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.29',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.29',
    #        DESC         => 'Bandwidth in lan',
    #        EQUALITY     => 'integerMatch',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scPrinterLanguage => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.30',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.30',
    #        DESC         => 'Printerlanguage, eg. ps | pcl',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scNic => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.36',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.36',
    #        DESC         => 'Networkinterfacemodulname',
    #        EQUALITY     => 'caseExactIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scPcibus => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.38',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.38',
    #        DESC         => 'Output of special commands, eg. lspci',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scPpd => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.39',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.39',
    #        DESC         => 'Postscriptprinterdescription: path',
    #        EQUALITY     => 'caseExactIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scRefImageDn => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.43',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.43',
    #        DESC         => 'DN of image to use',
    #        EQUALITY     => 'distinguishedNameMatch',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scRefPrinterDn => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.45',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.45',
    #        DESC         => 'DN to printer-hardwaretype, typically in global',
    #        EQUALITY     => 'distinguishedNameMatch',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scMonitorRes => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.46',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.46',
    #        DESC         => 'Possible resolutions for monitor',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scImageSize => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.50',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.50',
    #        DESC         => 'Size of the specific images',
    #        EQUALITY     => 'integerMatch',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scVsync => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.53',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.53',
    #        DESC         => 'Vertical range-frequency of monitor',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scWanBandWidth => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.54',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.54',
    #        DESC         => 'Bandwidth',
    #        EQUALITY     => 'integerMatch',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scInitRdScript => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.59',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.59',
    #        DESC         => 'Path or commands',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scPrinterDeviceUri => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.60',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.60',
    #        DESC         => 'Printer+Protocol+Port|Queue',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scPrinterDeviceUriOptional => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.61',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.61',
    #        DESC         => 'Printer+Protocol+Port|Queue',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scExcludeListRunning => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.62',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.62',
    #        DESC         => 'List of pathes',
    #        EQUALITY     => 'caseExactIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scCpuInfo => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.63',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.63',
    #        DESC         => 'Output of special commands, eg. /proc/cpuinfo',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scRamdiskFile => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.73',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.73',
    #        DESC         => 'Ramdiskfilename',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scRamdiskNumber => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.74',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.74',
    #        DESC         => 'Ramdisknumber',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scRamdiskSize => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.75',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.75',
    #        DESC         => 'Ramdisksize ',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scRamdiskDn => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.76',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.76',
    #        DESC         => 'Ramdisk Dn',
    #        EQUALITY     => 'distinguishedNameMatch',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.12',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scStartOption => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.77',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.77',
    #        DESC         => 'start option Syntax: x=y',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scBootConfigFileName => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.78',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.78',
    #        DESC         => 'Name of the Config-File for booting, fetched from tftp-server',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scDrivername => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.83',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.83',
    #        DESC         => 'Driver Modul',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scImageMd5 => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.88',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.88',
    #        DESC         => 'Md5 Sum of an Image',
    #        EQUALITY     => 'caseExactIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scPosImageDefaultVersion => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.102',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.102',
    #        DESC         => 'Default Version of an image',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
    #    scConfigFileUpdateModel => {
    #        OID          => '1.3.6.1.4.1.7057.10.3.4.1.108',
    #        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.108',
    #        DESC         => 'Update model for synching config files: pulled, changed',
    #        EQUALITY     => 'caseIgnoreIA5Match',
    #        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
    #        e_dn         => 'cn=schema',
    #        e_changetype => 'modify'
    #    },
);


############################################
# eDir attributes hash:
# used to generate edir.schema
#  contains attributes which are
#  in eDir only
#  in LDAP and eDir but different
############################################
%EDIR_ATTR_STRUCT = (
    uidNumber => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.120',
        DESC         => 'Unique ID Number for user',
        EQUALITY     => 'integerMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    memberNisNetgroup => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.121',
        EQUALITY     => 'caseExactIA5Match',
        SUBSTR       => 'caseExactIA5SubstringsMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    nisNetgroupTriple => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.122',
        DESC         => 'Netgroup triple',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    ipServicePort => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.123',
        DESC         => 'Service port number',
        EQUALITY     => 'integerMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    ipServiceProtocol => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.124',
        DESC         => 'Service protocol name',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    ipProtocolNumber => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.125',
        DESC         => 'IP protocol number',
        EQUALITY     => 'integerMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    oncRpcNumber => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.126',
        DESC         => 'ONC RPC number',
        EQUALITY     => 'integerMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    ipHostNumber => {
        EID      => '2.16.840.1.113719.1.453.1.1.1.1.1.127',
        DESC     => 'IPv4 addresses as a dotted decimal omitting leading zeros or IPv6 addresses as defined in RFC2373',
        EQUALITY => 'caseIgnoreIA5Match',
        SYNTAX   => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn     => 'cn=schema',
        e_changetype => 'modify'
    },
    ipNetworkNumber => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.128',
        DESC         => 'IP network as a dotted decimal, eg. 192.168, omitting leading zeros',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    ipNetmaskNumber => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.129',
        DESC         => 'IP netmask as a dotted decimal, eg. 255.255.255.0, omitting leading zeros',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    macAddress => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.130',
        DESC         => 'MAC address(es) in maximal, colon separated hex notation, eg. 00:00:92:90:EE:F2',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    bootParameter => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.131',
        DESC         => 'rpc.bootparamd parameter',
        EQUALITY     => 'caseExactIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    bootFile => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.132',
        DESC         => 'Boot image name',
        EQUALITY     => 'caseExactIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    nisMapName => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.133',
        DESC         => 'Name of a A generic NIS map',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    nisMapEntry => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.134',
        DESC         => 'A generic NIS entry',
        EQUALITY     => 'caseExactIA5Match',
        SUBSTR       => 'caseExactIA5SubstringsMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    nisPublicKey => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.135',
        DESC         => 'NIS public key',
        EQUALITY     => 'octetStringMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.40 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    nisSecretKey => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.136',
        DESC         => 'NIS secret key',
        EQUALITY     => 'octetStringMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.40 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    nisDomain => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.137',
        DESC         => 'NIS domain',
        EQUALITY     => 'caseIgnoreIA5Match',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    automountMapName => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.138',
        DESC         => 'automount Map Name',
        EQUALITY     => 'caseExactIA5Match',
        SUBSTR       => 'caseExactIA5SubstringsMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    automountKey => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.139',
        DESC         => 'Automount Key value',
        EQUALITY     => 'caseExactIA5Match',
        SUBSTR       => 'caseExactIA5SubstringsMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    automountInformation => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.140',
        DESC         => 'Automount information',
        EQUALITY     => 'caseExactIA5Match',
        SUBSTR       => 'caseExactIA5SubstringsMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    },
    associatedDomain => {
        EID          => '2.16.840.1.113719.1.453.1.1.1.1.1.141',
        DESC         => 'Domain associated with object',
        EQUALITY     => 'caseIgnoreIA5Match',
        SUBSTR       => 'caseIgnoreIA5SubstringsMatch',
        SYNTAX       => '1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE',
        e_dn         => 'cn=schema',
        e_changetype => 'modify'
    }
);

1;
